@@ -1,5 +1,5 @@
 create or replace function fast_win(a int4, b bigint) returns bool AS $$
-  is.null(farg2) || pg.throwerror('Constants shall not be passes with the frame')
+##is.null(farg2) || pg.throwerror('Constants shall not be passes with the frame')
   identical(parent.frame(), .GlobalEnv) && pg.throwerror('Parent env is global')
   exists('plr_window_frame', parent.frame(), inherits=FALSE) || pg.throwerror('No window frame data found')
   a == farg1[prownum]
