@@ -1,10 +1,5 @@
---
--- first, define the language and functions.  Turn off echoing so that expected file
--- does not depend on contents of plr.sql.
---
-\set ECHO none
-\i plr.sql
-\set ECHO all
+-- install extension
+create extension plr;
 
 -- make sure we get the notices
 set client_min_messages to notice;
@@ -512,7 +507,8 @@ CREATE OR REPLACE FUNCTION test_create_procedure() RETURNS void
   AS
 $BODY$
   version_11plus  <- pg.spi.exec("select current_setting('server_version_num')::integer >= 110000;")
-  if(version_11plus[[1]]) {
+  if(version_11plus[[1]])
+  {
     pg.spi.exec("
       CREATE OR REPLACE PROCEDURE insert_data(a int, b int)
         AS
@@ -522,7 +518,9 @@ $BODY$
       $$ LANGUAGE plr;
       ")
     pg.spi.exec("CALL insert_data(1, 2);")
-  } else {
+  }
+  else
+  {
     pg.spi.exec("INSERT INTO tbl VALUES (1);")
     pg.spi.exec("INSERT INTO tbl VALUES (2);")
   }
